@@ -54,13 +54,15 @@ def get_sequential_file_path(dir:Union[Path,str], basename:str, extension:str) -
     return res
 
 
+# ---------------------------------------------------------------------------------------------------------
 def _toPath(path:Union[str,Path]):
     if isinstance(path, str):
-        res = Path(str)
+        res = Path(path)
         return res
     else:
         return path
 
+# ---------------------------------------------------------------------------------------------------------
 def _toStr(path:Union[str,Path]):
     if isinstance(path, Path):
         res = str(path)
